@@ -1,31 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -62,15 +68,15 @@ public:
     QCameraFocusFakeZoomControl(QObject *parent) :
         QCameraZoomControl(parent) {}
 
-    qreal maximumOpticalZoom() const { return 1.0; }
-    qreal maximumDigitalZoom() const { return 1.0; }
+    qreal maximumOpticalZoom() const override { return 1.0; }
+    qreal maximumDigitalZoom() const override { return 1.0; }
 
-    qreal requestedOpticalZoom() const { return 1.0; }
-    qreal requestedDigitalZoom() const { return 1.0; }
-    qreal currentOpticalZoom() const { return 1.0; }
-    qreal currentDigitalZoom() const { return 1.0; }
+    qreal requestedOpticalZoom() const override { return 1.0; }
+    qreal requestedDigitalZoom() const override { return 1.0; }
+    qreal currentOpticalZoom() const override { return 1.0; }
+    qreal currentDigitalZoom() const override { return 1.0; }
 
-    void zoomTo(qreal, qreal) { qWarning("The camera doesn't support zooming."); }
+    void zoomTo(qreal, qreal) override { qWarning("The camera doesn't support zooming."); }
 };
 
 class QCameraFocusFakeFocusControl : public QCameraFocusControl
@@ -79,17 +85,17 @@ public:
     QCameraFocusFakeFocusControl(QObject *parent) :
         QCameraFocusControl(parent) {}
 
-    QCameraFocus::FocusModes focusMode() const { return QCameraFocus::AutoFocus; }
-    void setFocusMode(QCameraFocus::FocusModes) { qWarning("Focus mode selection is not supported"); }
-    bool isFocusModeSupported(QCameraFocus::FocusModes) const { return false; }
+    QCameraFocus::FocusModes focusMode() const override { return QCameraFocus::AutoFocus; }
+    void setFocusMode(QCameraFocus::FocusModes) override { qWarning("Focus mode selection is not supported"); }
+    bool isFocusModeSupported(QCameraFocus::FocusModes) const override { return false; }
 
-    QCameraFocus::FocusPointMode focusPointMode() const { return QCameraFocus::FocusPointAuto; }
-    void setFocusPointMode(QCameraFocus::FocusPointMode) { qWarning("Focus points mode selection is not supported"); }
-    bool isFocusPointModeSupported(QCameraFocus::FocusPointMode) const { return false; }
-    QPointF customFocusPoint() const { return QPointF(0.5,0.5); }
-    void setCustomFocusPoint(const QPointF &) { qWarning("Focus points selection is not supported"); }
+    QCameraFocus::FocusPointMode focusPointMode() const override { return QCameraFocus::FocusPointAuto; }
+    void setFocusPointMode(QCameraFocus::FocusPointMode) override { qWarning("Focus points mode selection is not supported"); }
+    bool isFocusPointModeSupported(QCameraFocus::FocusPointMode) const override { return false; }
+    QPointF customFocusPoint() const override { return QPointF(0.5,0.5); }
+    void setCustomFocusPoint(const QPointF &) override { qWarning("Focus points selection is not supported"); }
 
-    QCameraFocusZoneList focusZones() const { return QCameraFocusZoneList(); }
+    QCameraFocusZoneList focusZones() const override { return QCameraFocusZoneList(); }
 };
 
 
